<?php
/**
 * @package Solar Services
 * Setup the WordPress core custom header feature.
 *
 * @uses solar_services_header_style()
 */
function solar_services_custom_header_setup() {
	add_theme_support( 'custom-header', apply_filters( 'solar_services_custom_header_args', array(
		'default-text-color'     => 'fff',
		'width'                  => 2500,
		'height'                 => 400,
		'wp-head-callback'       => 'solar_services_header_style',
	) ) );
}
add_action( 'after_setup_theme', 'solar_services_custom_header_setup' );

if ( ! function_exists( 'solar_services_header_style' ) ) :
/**
 * Styles the header image and text displayed on the blog
 *
 * @see solar_services_custom_header_setup().
 */
function solar_services_header_style() {
	$header_text_color = get_header_textcolor();
	?>
	<style type="text/css">
	<?php
		//Check if user has defined any header image.
		if ( get_header_image() || get_header_textcolor() ) :
	?>
		.header-image {
			background: url(<?php echo esc_url( get_header_image() ); ?>) no-repeat;
			background-position: center top;
			background-size: cover;
			height:400px;
		}
	<?php endif; ?>	


	h1.site-title a {
		color: <?php echo esc_attr(get_theme_mod('solar_services_sitetitle_color')); ?>;
	}
	

	.header .tophead {
		background: <?php echo esc_attr(get_theme_mod('solar_services_headertopbg_color')); ?>;
	}


	.header .site-mail .fa-phone {
		color: <?php echo esc_attr(get_theme_mod('solar_services_headerphoneicon_color')); ?>;
	}

	.header .site-mail .fa-phone {
		background: <?php echo esc_attr(get_theme_mod('solar_services_headerphoneiconbg_color')); ?>;
	}

	.header .phn p {
		color: <?php echo esc_attr(get_theme_mod('solar_services_headerphonetext_color')); ?>;
	}

	.header .phn p:hover {
		color: <?php echo esc_attr(get_theme_mod('solar_services_headerphonehover_color')); ?>;
	}


	.header .site-mail .fa-envelope {
		color: <?php echo esc_attr(get_theme_mod('solar_services_headeremailicon_color')); ?>;
	}

	.header .site-mail .fa-envelope {
		background: <?php echo esc_attr(get_theme_mod('solar_services_headeremailiconbg_color')); ?>;
	}

	.header .email p{
		color: <?php echo esc_attr(get_theme_mod('solar_services_headeremailtext_color')); ?>;
	}

	.header .email p:hover {
		color: <?php echo esc_attr(get_theme_mod('solar_services_headeremailhover_color')); ?>;
	}

	.social-icons .fa-facebook-f {
		color: <?php echo esc_attr(get_theme_mod('solar_services_headerfbicon_color')); ?>;
	}

	.social-icons .fa-twitter {
		color: <?php echo esc_attr(get_theme_mod('solar_services_headertwitt_color')); ?>;
	}

	.social-icons .fa-linkedin {
		color: <?php echo esc_attr(get_theme_mod('solar_services_headerLinkdin_color')); ?>;
	}

	.social-icons .fa-instagram  {
		color: <?php echo esc_attr(get_theme_mod('solar_services_headerInstagram_color')); ?>;
	}


	.header .social-icons i {
		background: <?php echo esc_attr(get_theme_mod('solar_services_headericonsbg_color')); ?>;
	}

	.header .social-icons i:hover {
		color: <?php echo esc_attr(get_theme_mod('solar_services_headericonshover_color')); ?>;
	}

	.header {
		background: <?php echo esc_attr(get_theme_mod('solar_services_headermenusbg_color')); ?>;
	}

	.main-nav a {
		color: <?php echo esc_attr(get_theme_mod('solar_services_headermenu_color')); ?>;
	}

	.main-nav a:hover, .current_page_item a {
		color: <?php echo esc_attr(get_theme_mod('solar_services_headermenuhover_color')); ?>;
	}

	.main-nav ul ul a {
		color: <?php echo esc_attr(get_theme_mod('solar_services_headersubmenu_color')); ?>;
	}

	.main-nav ul ul a:hover {
		color: <?php echo esc_attr(get_theme_mod('solar_services_headersubmenuhover_color')); ?>;
	}

	.main-nav ul ul {
		background: <?php echo esc_attr(get_theme_mod('solar_services_headersubmenubg_color')); ?>;
	}

	.main-nav ul ul li {
		border-color: <?php echo esc_attr(get_theme_mod('solar_services_headersubmenuborder_color')); ?>;
	}

	.header-btn a {
		color: <?php echo esc_attr(get_theme_mod('solar_services_headerbtntext_color')); ?>;
	}

	.header-btn a {
		border-color: <?php echo esc_attr(get_theme_mod('solar_services_headerbtntextborder_color')); ?>;
	}

	.header-btn a {
		background: <?php echo esc_attr(get_theme_mod('solar_services_headerbtntextbg_color')); ?>;
	}

	.header-btn a:hover {
		background: <?php echo esc_attr(get_theme_mod('solar_services_headerbtntexthover_color')); ?>;
	}

	




	#catsliderarea .catwrapslider .big-title {
		color: <?php echo esc_attr(get_theme_mod('solar_services_slidertitle_color')); ?> !important;		

	}


	.slider-box .slider-btn .btn1 {
		color: <?php echo esc_attr(get_theme_mod('solar_services_sliderbtntext_color')); ?> !important;				
	}

	.slider-box .slider-btn .btn1 {
		background-color: <?php echo esc_attr(get_theme_mod('solar_services_sliderbtnbg_color')); ?> !important;				
	}

	.slider-box .slider-btn .btn1 {
		border-color: <?php echo esc_attr(get_theme_mod('solar_services_sliderbtnborder_color')); ?> !important;				
	}

	.slider-box .slider-btn .btn2 {
		color: <?php echo esc_attr(get_theme_mod('solar_services_sliderbtntext2_color')); ?> !important;				
	}

	.slider-box .slider-btn .btn2 {
		background-color: <?php echo esc_attr(get_theme_mod('solar_services_sliderbtnbg2_color')); ?> !important;				
	}

	.slider-box .slider-btn .btn2 {
		border-color: <?php echo esc_attr(get_theme_mod('solar_services_sliderbtnborder2_color')); ?> !important;				
	}

	#feature_box .fea_bx {
		background: <?php echo esc_attr(get_theme_mod('solar_services_featureleftboxbg_color')); ?>;				
	}

	#feature_box .fea_bx h2 {
		color: <?php echo esc_attr(get_theme_mod('solar_services_featureleftheading_color')); ?>;				
	}

	#feature_box .fea_bx p {
		color: <?php echo esc_attr(get_theme_mod('solar_services_featureleftdescription_color')); ?>;				
	}

	#feature_box .fea_bx li {
		color: <?php echo esc_attr(get_theme_mod('solar_services_featureleftlist_color')); ?>;				
	}

	#feature_box .feature-btn a {
		color: <?php echo esc_attr(get_theme_mod('solar_services_featureleftbtntxt_color')); ?>;				
	}

	#feature_box .feature-btn a {
		background: <?php echo esc_attr(get_theme_mod('solar_services_featureleftbtnbg_color')); ?>;				
	}

	#feature_box .feature-btn a {
		border-color: <?php echo esc_attr(get_theme_mod('solar_services_featureleftbtnborder_color')); ?>;				
	}




	.fea-rhs {
		background: <?php echo esc_attr(get_theme_mod('solar_services_featurebg_color')); ?>;
	}

	.feature_inner_box {
		background: <?php echo esc_attr(get_theme_mod('solar_services_featureboxbg_color')); ?>;
	}

	.feature_inner_box .feature-title a {
		color: <?php echo esc_attr(get_theme_mod('solar_services_featurehead_color')); ?>;
	}





	#blog .subhed {
		color: <?php echo esc_attr(get_theme_mod('solar_services_blogheading_color')); ?>;
	}

	#blog h1 {
		color: <?php echo esc_attr(get_theme_mod('solar_services_blogheadingcontent_color')); ?> !important;
	}

	#blog .blog {
		background: <?php echo esc_attr(get_theme_mod('solar_services_blogboxbg_color')); ?>;
	}


	#blog h4 {
		color: <?php echo esc_attr(get_theme_mod('solar_services_blogtitle_color')); ?> !important;
	}

	#blog .content p {
		color: <?php echo esc_attr(get_theme_mod('solar_services_blogdescription_color')); ?> !important;
	}

	#blog .blog-btn a {
		color: <?php echo esc_attr(get_theme_mod('solar_services_blogebtntxt_color')); ?> !important;
	}

	#blog .blog-btn a {
		background: <?php echo esc_attr(get_theme_mod('solar_services_blogebtnbg_color')); ?>;
	}






	#footer {
		background-color: <?php echo esc_attr(get_theme_mod('solar_services_footerbg_color')); ?> ;		
	}

	#footer .copywrap a {
		color: <?php echo esc_attr(get_theme_mod('solar_services_footercoypright_color')); ?>;		
	}

	#footer .footer-bottom, #footer .copywrap {
		background-color: <?php echo esc_attr(get_theme_mod('solar_services_footercoyprightbg_color')); ?> ;		
	}
	
	#footer .ftr-4-box h3, #footer .ftr-4-box h2 {
		color: <?php echo esc_attr(get_theme_mod('solar_services_footerheading_color')); ?>;		
	}

	#footer .ftr-4-box ul li a, #footer .ftr-4-box a {
		color: <?php echo esc_attr(get_theme_mod('solar_services_footerlist_color')); ?>;		
	}

	#footer aside.widget ul li:before {
		color: <?php echo esc_attr(get_theme_mod('solar_services_footerlisticon_color')); ?>;		
	}

	#footer .ftr-4-box a:hover, #footer .ftr-4-box a:hover {
		color: <?php echo esc_attr(get_theme_mod('solar_services_footerlisthover_color')); ?>;		
	}

	#footer .ftr-4-box p {
		color: <?php echo esc_attr(get_theme_mod('solar_services_footertext_color')); ?>;		
	}
	

	</style>
	<?php 
}
endif;